==> haskell-equivalence-0.3.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.1
id: equivalence-0.3.1-K2wbMNHB6xL40Xur1iwWlO
key: equivalence-0.3.1-K2wbMNHB6xL40Xur1iwWlO
license: BSD3
maintainer: paba@di.ku.dk
stability: provisional
homepage: https://bitbucket.org/paba/equivalence/
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
author: Patrick Bahr
exposed: True
exposed-modules:
    Data.Equivalence.STT Data.Equivalence.Monad
abi: 49c9e143b55469f09e70da0f9de1fb38
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/equivalence-0.3.1
hs-libraries: HSequivalence-0.3.1-K2wbMNHB6xL40Xur1iwWlO
depends:
    STMonadTrans-0.3.4-8cQrHWbnDEL30NLdJ0qlZ8 base-4.9.0.0
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.2
id: equivalence-0.3.2-AbeI8DCV8sT6eoJWDibbaO
key: equivalence-0.3.2-AbeI8DCV8sT6eoJWDibbaO
license: BSD3
maintainer: paba@di.ku.dk
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
author: Patrick Bahr
exposed: True
exposed-modules:
    Data.Equivalence.STT Data.Equivalence.Monad
abi: 39469ac4b03fe6867ab7eb49842d36a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/equivalence-0.3.2
hs-libraries: HSequivalence-0.3.2-AbeI8DCV8sT6eoJWDibbaO
depends:
    STMonadTrans-0.4.3-9CbqniG6MqK81b1oifQGh base-4.9.0.0
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
